#
# spec file for package gnome-autoar
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gnome-autoar
Version:        0.4.5
Release:        1.1
Summary:        Automatic archives creating and extracting library
License:        LGPL-2.0-or-later
Group:          System/GUI/GNOME
URL:            https://gitlab.gnome.org/GNOME/gnome-autoar
# Sourceurl disabled, as we are using a git checkout via source services
#Source0:       https://download.gnome.org/sources/gnome-autoar/0.4/%%{name}-%%{version}.tar.xz
Source0:        %{name}-%{version}.tar.xz

BuildRequires:  gtk-doc
BuildRequires:  meson >= 0.56.0
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(gio-2.0) >= 2.35.6
BuildRequires:  pkgconfig(glib-2.0) >= 2.35.6
BuildRequires:  pkgconfig(gobject-2.0) >= 2.35.6
BuildRequires:  pkgconfig(gobject-introspection-1.0) >= 1.30.0
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.2
BuildRequires:  pkgconfig(libarchive) >= 3.4.0
BuildRequires:  pkgconfig(vapigen)

%description
gnome-autoar provides functions, widgets, and gschemas for GNOME applications which want
to use archives as a method to transfer directories over the Internet.

%package -n libgnome-autoar-0-0
Summary:        Automatic archives creating and extracting library
Group:          System/Libraries
Obsoletes:      gnome-autoar-schema

%description -n libgnome-autoar-0-0
gnome-autoar provides functions, widgets, and gschemas for GNOME applications which want
to use archives as a method to transfer directories over the Internet.

%package -n libgnome-autoar-gtk-0-0
Summary:        Automatic archives creating and extracting library
Group:          System/Libraries

%description -n libgnome-autoar-gtk-0-0
gnome-autoar provides functions, widgets, and gschemas for GNOME applications which want
to use archives as a method to transfer directories over the Internet.

%package -n typelib-1_0-GnomeAutoar-0_1
Summary:        Automatic archives creating and extracting library -- Introspection bindings
Group:          System/Libraries

%description -n typelib-1_0-GnomeAutoar-0_1
gnome-autoar provides functions, widgets, and gschemas for GNOME applications which want
to use archives as a method to transfer directories over the Internet.

%package -n typelib-1_0-GnomeAutoarGtk-0_1
Summary:        Automatic archives creating and extracting library -- Introspection bindings
Group:          System/Libraries

%description -n typelib-1_0-GnomeAutoarGtk-0_1
gnome-autoar provides functions, widgets, and gschemas for GNOME applications which want
to use archives as a method to transfer directories over the Internet.

%package devel
Summary:        Automatic archives creating and extracting library
Group:          Development/Languages/C and C++
Requires:       libgnome-autoar-0-0 = %{version}
Requires:       libgnome-autoar-gtk-0-0 = %{version}
Requires:       typelib-1_0-GnomeAutoar-0_1 = %{version}
Requires:       typelib-1_0-GnomeAutoarGtk-0_1 = %{version}

%description devel
gnome-autoar provides functions, widgets, and gschemas for GNOME applications which want
to use archives as a method to transfer directories over the Internet.

This package brings files required to develop against gnome-autoar

%prep
%autosetup -p1

%build
%meson \
	-D vapi=true \
	-D gtk_doc=true \
	-D tests=true \
	%{nil}
%meson_build

%install
%meson_install

%check
%meson_test

%ldconfig_scriptlets -n libgnome-autoar-0-0
%ldconfig_scriptlets -n libgnome-autoar-gtk-0-0

%files devel
%{_includedir}/gnome-autoar-0/
%{_libdir}/libgnome-autoar-0.so
%{_libdir}/libgnome-autoar-gtk-0.so
%{_libdir}/pkgconfig/gnome-autoar-0.pc
%{_libdir}/pkgconfig/gnome-autoar-gtk-0.pc
%{_datadir}/gir-1.0/GnomeAutoar-0.1.gir
%{_datadir}/gir-1.0/GnomeAutoarGtk-0.1.gir
%{_datadir}/gtk-doc/html/%{name}/
%dir %{_datadir}/vala/vapi
%{_datadir}/vala/vapi/gnome-autoar-0.vapi
%{_datadir}/vala/vapi/gnome-autoar-gtk-0.vapi
%{_datadir}/vala/vapi/gnome-autoar-0.deps
%{_datadir}/vala/vapi/gnome-autoar-gtk-0.deps

%files -n typelib-1_0-GnomeAutoar-0_1
%{_libdir}/girepository-1.0/GnomeAutoar-0.1.typelib

%files -n typelib-1_0-GnomeAutoarGtk-0_1
%{_libdir}/girepository-1.0/GnomeAutoarGtk-0.1.typelib

%files -n libgnome-autoar-0-0
%license COPYING
%{_libdir}/libgnome-autoar-0.so.*

%files -n libgnome-autoar-gtk-0-0
%{_libdir}/libgnome-autoar-gtk-0.so.*

%changelog
* Fri Aug 30 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.4.5:
  + mime-types: Add tar variant of bzip2
  + extractor: Fix source string leak
* Fri Mar 17 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.4.4:
  + Add application/zstd to supported mime-types.
  + Fix test suite failure with recent GLib version.
  + Add autoar_extractor_set_passphrase function.
* Mon Mar 13 2023 bjorn.lie@gmail.com
- Update to version 0.4.3+9:
  + ci:
  - Drop workaround to remove mount options
  - Explicitiely set the storage driver
  - Use rawhide for the fedora job
  + extractor:
  - Add autoar_extractor_set_passphrase function
  - Fix parameter name in documentation comment
  - Make error codes public
  - Use g_file_info_remove_attribute instead of invalid type
  - Use specific error code when passphrase wasn't provided
  + tests: Skip file size check for directories
- Switch to git checkout via source service.
- Enable test macro again as upstream fixed the issue.
* Fri Mar 10 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Temp disable test due to changes in new glib2 2.76.0 release:
  wait for upstream to fix in either glib or in gnome-autoar.
  https://gitlab.gnome.org/GNOME/gnome-autoar/-/issues/44
* Fri Feb 11 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.4.3:
  + Prevent NULL dereference when extracting to root.
  + Do not include basename in error messages.
  + Do not request password when encryption is unsupported.
  + Propagate libarchive errors when extraction failed.
* Fri Jan  7 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 0.4.2:
  + Fix extraction to root directory.
  + Fix extraction of raw format archives.
  + Do not leave read-only directory in the tree after running
    tests.
* Sat Oct 30 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.4.1:
  + Fix regression of extraction in symlinked locations.
  + Handle passphrase prompt cancellation to prevent showing error
    dialogs.
  + Downgrade meson dependency to 0.56.0.
- Replace post(un) handling with new ldconfig_scriptlets macro.
- Add check section and meson_test macro, as well as pass
  tests=true to meson, run tests during build.
* Tue Aug 10 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.4.0:
  + Port to meson build system.
  + Add support for creation of password-protected archives.
  + Fix extraction of archives with absolute paths.
- Add meson BuildRequires and macros following upstreams port.
- Add gtk-doc BuildRequires and pass gtk_doc=true to meson, needed
  now to build documentation.
- Pass vapi=true to meson, needed to build vala bindings.
* Fri Jul 30 2021 Yifan Jiang <yfjiang@suse.com>
- Drop gnome-autoar-CVE-2020-36241.patch on SLE and Leap 15.4:
  fixed upstream.
* Fri Jun  4 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.3.3:
  + extractor: Fix extraction of one file archives
  + compressor: Fix usage of uninitialized value
* Fri Apr 30 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 0.3.2:
  + compressor:
  - Fix hardlink handling for new cpio format.
  - Fix hardlink detection for remote files.
  + extractor: Fix extraction of readonly folders.
* Wed Apr 14 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 0.3.1:
  + Disallow symlinks in parents completely when extracting
    ( CVE-2021-28650 )
  + Drop recursive delete on failure to prevent data loss
  + Add back RAR support
* Mon Feb 22 2021 Alynx Zhou <alynx.zhou@suse.com>
- Add gnome-autoar-CVE-2020-36241.patch: Skip problematic files
  that might be extracted outside of the destination dir to prevent
  potential security threat. (bsc#1181930,
  glgo#GNOME/gnome-autoar#7)
* Fri Feb 12 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.3.0:
  + Recognize MIME type aliases of extractable archives.
  + Add extraction support for password-protected archives.
  + CVE-2020-36241: Prevent extraction outside the destination dir.
* Fri Dec 13 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.2.4:
  + Use autoreconf instead of deprecated gnome-common.
* Mon Feb 26 2018 bjorn.lie@gmail.com
- Update to version 0.2.3:
  + Use proper extracted name for xz archives.
  + Fix decompressing files with legacy encoding file names.
- Run spec-cleaner, modernize spec, use autosetup and make_build
  macros.
* Tue Mar 21 2017 dimstar@opensuse.org
- Update to version 0.2.2:
  + Fix docx files and other format subtypes of zip to be
    uncompressed.
* Fri Mar  3 2017 zaitor@opensuse.org
- Update to version 0.2.1:
  + Drop rar support since rar5 is not yet supported by libarchive.
* Thu Feb 23 2017 zaitor@opensuse.org
- Update to version 0.2.0:
  + Generate vala bindings.
  + Check encrypted entry after header is read.
  + Fix extraction name case, e.j.'sample.odt' in 'sample.odt.zip'.
  + Remove GSettings schema files.
- Add pkgconfig(vapigen) BuildRequires: New dependency for vala
  bindings.
- Pass --enable-gtk to configure, ensure we build gtk3 widgets.
- Drop gnome-autoar-schema subpackage and add gnome-autoar-schema
  Obsoletes replacing previous Requires, following upstream
  changes.
* Fri Sep  2 2016 zaitor@opensuse.org
- Updated to version 0.1.1:
  + Fix library link issues for Evolution.
  + Make decide destination signal synchronous for Evolution.
  + Fix licence to LGPLv2.1+.
* Thu Sep  1 2016 zaitor@opensuse.org
- Update to version 0.1.0:
  + Bump required libarchive version.
  + AutoarExtractor: signal error on encrypted archives.
  + Add COPYING file.
  + tests: Add missing linker flags.
- Stop using sourceservice, tarball release now available.
- Following the above: gnome-common BuildRequires and autogen.sh
  call: We no longer need to bootstrap.
* Wed Aug 31 2016 dimstar@opensuse.org
- Initial package, version 0+20160825.0fec26d (no tagged release
  yet available in git).
